==> jc-hsufuchifoods-domain-0.0.20-sources.jar: com/xforceplus/jchsufuchifoods/metadata/EntityMeta.java <==
package com.xforceplus.jchsufuchifoods.metadata;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.xforceplus.ultraman.bocp.gen.typed.TypedField;


/**
* <p>
    * 
    * </p>
*
* @author ultraman
* @since 2021-06-21
*/

public class EntityMeta {

    public interface GeneralRuleConfig {
        static Long id() {
            return 1402887741181702146L;
        }
        static String code() {
            return "generalRuleConfig";
        }
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<String> SELLERNAME = new TypedField<>(String.class, "sellerName");
        TypedField<String> CUSTOMERLEVEL6 = new TypedField<>(String.class, "customerLevel6");
        TypedField<String> PURCHASERTAXNO = new TypedField<>(String.class, "purchaserTaxNo");
        TypedField<String> PURCHASERNAME = new TypedField<>(String.class, "purchaserName");
        TypedField<BigDecimal> WARNINGDISCOUNTRATE = new TypedField<>(BigDecimal.class, "warningDiscountRate");
        TypedField<BigDecimal> ERRORDISCOUNTRATE = new TypedField<>(BigDecimal.class, "errorDiscountRate");
        TypedField<BigDecimal> SINGLEMAXAMOUNT = new TypedField<>(BigDecimal.class, "singleMaxAmount");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<String> RULECONFIGTYPE = new TypedField<>(String.class, "ruleConfigType");
        TypedField<String> PRICEQUANTITYMETHOD = new TypedField<>(String.class, "priceQuantityMethod");
    }

    public interface SellerInfoConfig {
        static Long id() {
            return 1405818125934825473L;
        }
        static String code() {
            return "sellerInfoConfig";
        }
        TypedField<String> SELLERNO = new TypedField<>(String.class, "sellerNo");
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
    }

    public interface RedLetterInvoiceMain {
        static Long id() {
            return 1405839343480115202L;
        }
        static String code() {
            return "redLetterInvoiceMain";
        }
        TypedField<String> DEVICEUN = new TypedField<>(String.class, "deviceUn");
        TypedField<String> TERMINALUN = new TypedField<>(String.class, "terminalUn");
        TypedField<String> APPLYSERIALNO = new TypedField<>(String.class, "applySerialNo");
        TypedField<String> OILMEMO = new TypedField<>(String.class, "oilMemo");
        TypedField<String> BUYERTAXNO = new TypedField<>(String.class, "buyerTaxNo");
        TypedField<String> BUYERNAME = new TypedField<>(String.class, "buyerName");
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<String> SELLERNAME = new TypedField<>(String.class, "sellerName");
        TypedField<String> ORIGININVOICECODE = new TypedField<>(String.class, "originInvoiceCode");
        TypedField<String> ORIGININVOICENO = new TypedField<>(String.class, "originInvoiceNo");
        TypedField<String> ORIGININVOICETYPE = new TypedField<>(String.class, "originInvoiceType");
        TypedField<String> ORIGINDATEISSUED = new TypedField<>(String.class, "originDateIssued");
        TypedField<String> APPLICATIONREASON = new TypedField<>(String.class, "applicationReason");
        TypedField<BigDecimal> AMOUNTWITHOUTTAX = new TypedField<>(BigDecimal.class, "amountWithoutTax");
        TypedField<BigDecimal> AMOUNTWITHTAX = new TypedField<>(BigDecimal.class, "amountWithTax");
        TypedField<BigDecimal> TAXAMOUNT = new TypedField<>(BigDecimal.class, "taxAmount");
        TypedField<Long> ORIGININVOICEID = new TypedField<>(Long.class, "originInvoiceId");
        TypedField<String> STATUS = new TypedField<>(String.class, "status");
        TypedField<String> APPLYTASKID = new TypedField<>(String.class, "applyTaskId");
        TypedField<String> APPLYRESULT = new TypedField<>(String.class, "applyResult");
        TypedField<String> CANCELTASKID = new TypedField<>(String.class, "cancelTaskId");
        TypedField<String> CANCELRESULT = new TypedField<>(String.class, "cancelResult");
        TypedField<String> REDLETTERNUMBER = new TypedField<>(String.class, "redLetterNumber");
        TypedField<String> APPLYSTATUS = new TypedField<>(String.class, "applyStatus");
        TypedField<LocalDateTime> APPLYTIME = new TypedField<>(LocalDateTime.class, "applyTime");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
    }

    public interface SalesBillMain {
        static Long id() {
            return 1406581300212961282L;
        }
        static String code() {
            return "salesBillMain";
        }
        TypedField<String> BUSINESSBILLTYPE = new TypedField<>(String.class, "businessBillType");
        TypedField<String> TERMINALCODE = new TypedField<>(String.class, "terminalCode");
        TypedField<String> SYSTEMORIG = new TypedField<>(String.class, "systemOrig");
        TypedField<String> STATUS = new TypedField<>(String.class, "status");
        TypedField<String> SALESBILLNO = new TypedField<>(String.class, "salesbillNo");
        TypedField<BigDecimal> AMOUNTWITHTAX = new TypedField<>(BigDecimal.class, "amountWithTax");
        TypedField<BigDecimal> OUTERDISCOUNTWITHTAX = new TypedField<>(BigDecimal.class, "outerDiscountWithTax");
        TypedField<BigDecimal> AMOUNTWITHOUTTAX = new TypedField<>(BigDecimal.class, "amountWithoutTax");
        TypedField<BigDecimal> TAXAMOUNT = new TypedField<>(BigDecimal.class, "taxAmount");
        TypedField<String> INVOICETYPE = new TypedField<>(String.class, "invoiceType");
        TypedField<String> PRICEMETHOD = new TypedField<>(String.class, "priceMethod");
        TypedField<String> REMARK = new TypedField<>(String.class, "remark");
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<String> SELLERNAME = new TypedField<>(String.class, "sellerName");
        TypedField<String> SELLERADDRESS = new TypedField<>(String.class, "sellerAddress");
        TypedField<String> SELLERTEL = new TypedField<>(String.class, "sellerTel");
        TypedField<String> SELLERBANKNAME = new TypedField<>(String.class, "sellerBankName");
        TypedField<String> SELLERBANKACCOUNT = new TypedField<>(String.class, "sellerBankAccount");
        TypedField<String> PURCHASERNO = new TypedField<>(String.class, "purchaserNo");
        TypedField<String> CASHIERNAME = new TypedField<>(String.class, "cashierName");
        TypedField<String> CHECKERNAME = new TypedField<>(String.class, "checkerName");
        TypedField<String> INVOICERNAME = new TypedField<>(String.class, "invoicerName");
        TypedField<String> RECEIVEUSEREMAIL = new TypedField<>(String.class, "receiveUserEmail");
        TypedField<String> SALESBILLTYPE = new TypedField<>(String.class, "salesbillType");
        TypedField<String> EXT1 = new TypedField<>(String.class, "ext1");
        TypedField<String> EXT2 = new TypedField<>(String.class, "ext2");
        TypedField<String> EXT3 = new TypedField<>(String.class, "ext3");
        TypedField<String> ORIGININVOICENO = new TypedField<>(String.class, "originInvoiceNo");
        TypedField<String> ORIGININVOICECODE = new TypedField<>(String.class, "originInvoiceCode");
        TypedField<String> REDNOTIFICATION = new TypedField<>(String.class, "redNotification");
        TypedField<String> PROCESSSTATUS = new TypedField<>(String.class, "processStatus");
        TypedField<String> PROCESSRESULT = new TypedField<>(String.class, "processResult");
        TypedField<String> PROCESSREMARK = new TypedField<>(String.class, "processRemark");
        TypedField<String> PURCHASERADDRESS = new TypedField<>(String.class, "purchaserAddress");
        TypedField<String> PURCHASERBANKACCOUNT = new TypedField<>(String.class, "purchaserBankAccount");
        TypedField<String> PURCHASERBANKNAME = new TypedField<>(String.class, "purchaserBankName");
        TypedField<String> PURCHASERBANKNAMEACCOUNT = new TypedField<>(String.class, "purchaserBankNameAccount");
        TypedField<String> PURCHASERNAME = new TypedField<>(String.class, "purchaserName");
        TypedField<String> PURCHASERTAXNO = new TypedField<>(String.class, "purchaserTaxNo");
        TypedField<String> PURCHASERTEL = new TypedField<>(String.class, "purchaserTel");
        TypedField<String> EXT4 = new TypedField<>(String.class, "ext4");
        TypedField<String> EXT5 = new TypedField<>(String.class, "ext5");
        TypedField<String> SYSORGCODE = new TypedField<>(String.class, "sysOrgCode");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<Long> USINGSTATUS = new TypedField<>(Long.class, "usingStatus");
        TypedField<String> SELLERNO = new TypedField<>(String.class, "sellerNo");
    }

    public interface SalesBillDetails {
        static Long id() {
            return 1406626505695858690L;
        }
        static String code() {
            return "salesBillDetails";
        }
        TypedField<String> SALESBILLITEMNO = new TypedField<>(String.class, "salesbillItemNo");
        TypedField<String> ITEMNAME = new TypedField<>(String.class, "itemName");
        TypedField<String> ITEMSPEC = new TypedField<>(String.class, "itemSpec");
        TypedField<String> QUANTITYUNIT = new TypedField<>(String.class, "quantityUnit");
        TypedField<BigDecimal> UNITPRICE = new TypedField<>(BigDecimal.class, "unitPrice");
        TypedField<BigDecimal> DEDUCTION = new TypedField<>(BigDecimal.class, "deduction");
        TypedField<BigDecimal> QUANTITY = new TypedField<>(BigDecimal.class, "quantity");
        TypedField<BigDecimal> AMOUNTWITHOUTTAX = new TypedField<>(BigDecimal.class, "amountWithoutTax");
        TypedField<BigDecimal> TAXRATE = new TypedField<>(BigDecimal.class, "taxRate");
        TypedField<BigDecimal> TAXAMOUNT = new TypedField<>(BigDecimal.class, "taxAmount");
        TypedField<BigDecimal> AMOUNTWITHTAX = new TypedField<>(BigDecimal.class, "amountWithTax");
        TypedField<BigDecimal> OUTERDISCOUNTWITHTAX = new TypedField<>(BigDecimal.class, "outerDiscountWithTax");
        TypedField<String> GOODSTAXNO = new TypedField<>(String.class, "goodsTaxNo");
        TypedField<String> TAXCONVERTCODE = new TypedField<>(String.class, "taxConvertCode");
        TypedField<String> TAXPRE = new TypedField<>(String.class, "taxPre");
        TypedField<String> TAXPRECON = new TypedField<>(String.class, "taxPreCon");
        TypedField<String> ZEROTAX = new TypedField<>(String.class, "zeroTax");
        TypedField<String> EXT1 = new TypedField<>(String.class, "ext1");
        TypedField<String> EXT2 = new TypedField<>(String.class, "ext2");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
    }

}

==> jc-hsufuchifoods-domain-0.0.23-sources.jar: com/xforceplus/jchsufuchifoods/metadata/EntityMeta.java <==
package com.xforceplus.jchsufuchifoods.metadata;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.xforceplus.ultraman.bocp.gen.typed.TypedField;


/**
* <p>
    * 
    * </p>
*
* @author ultraman
* @since 2021-06-23
*/

public class EntityMeta {

    public interface GeneralRuleConfig {
        static Long id() {
            return 1402887741181702146L;
        }
        static String code() {
            return "generalRuleConfig";
        }
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<String> SELLERNAME = new TypedField<>(String.class, "sellerName");
        TypedField<String> CUSTOMERLEVEL6 = new TypedField<>(String.class, "customerLevel6");
        TypedField<String> PURCHASERTAXNO = new TypedField<>(String.class, "purchaserTaxNo");
        TypedField<String> PURCHASERNAME = new TypedField<>(String.class, "purchaserName");
        TypedField<BigDecimal> WARNINGDISCOUNTRATE = new TypedField<>(BigDecimal.class, "warningDiscountRate");
        TypedField<BigDecimal> ERRORDISCOUNTRATE = new TypedField<>(BigDecimal.class, "errorDiscountRate");
        TypedField<BigDecimal> SINGLEMAXAMOUNT = new TypedField<>(BigDecimal.class, "singleMaxAmount");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<String> RULECONFIGTYPE = new TypedField<>(String.class, "ruleConfigType");
        TypedField<String> PRICEQUANTITYMETHOD = new TypedField<>(String.class, "priceQuantityMethod");
    }

    public interface SellerInfoConfig {
        static Long id() {
            return 1405818125934825473L;
        }
        static String code() {
            return "sellerInfoConfig";
        }
        TypedField<String> SELLERNO = new TypedField<>(String.class, "sellerNo");
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
    }

    public interface RedLetterInvoiceMain {
        static Long id() {
            return 1405839343480115202L;
        }
        static String code() {
            return "redLetterInvoiceMain";
        }
        TypedField<String> DEVICEUN = new TypedField<>(String.class, "deviceUn");
        TypedField<String> TERMINALUN = new TypedField<>(String.class, "terminalUn");
        TypedField<String> APPLYSERIALNO = new TypedField<>(String.class, "applySerialNo");
        TypedField<String> OILMEMO = new TypedField<>(String.class, "oilMemo");
        TypedField<String> BUYERTAXNO = new TypedField<>(String.class, "buyerTaxNo");
        TypedField<String> BUYERNAME = new TypedField<>(String.class, "buyerName");
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<String> SELLERNAME = new TypedField<>(String.class, "sellerName");
        TypedField<String> ORIGININVOICECODE = new TypedField<>(String.class, "originInvoiceCode");
        TypedField<String> ORIGININVOICENO = new TypedField<>(String.class, "originInvoiceNo");
        TypedField<String> ORIGININVOICETYPE = new TypedField<>(String.class, "originInvoiceType");
        TypedField<String> ORIGINDATEISSUED = new TypedField<>(String.class, "originDateIssued");
        TypedField<String> APPLICATIONREASON = new TypedField<>(String.class, "applicationReason");
        TypedField<BigDecimal> AMOUNTWITHOUTTAX = new TypedField<>(BigDecimal.class, "amountWithoutTax");
        TypedField<BigDecimal> AMOUNTWITHTAX = new TypedField<>(BigDecimal.class, "amountWithTax");
        TypedField<BigDecimal> TAXAMOUNT = new TypedField<>(BigDecimal.class, "taxAmount");
        TypedField<Long> ORIGININVOICEID = new TypedField<>(Long.class, "originInvoiceId");
        TypedField<String> STATUS = new TypedField<>(String.class, "status");
        TypedField<String> APPLYTASKID = new TypedField<>(String.class, "applyTaskId");
        TypedField<String> APPLYRESULT = new TypedField<>(String.class, "applyResult");
        TypedField<String> CANCELTASKID = new TypedField<>(String.class, "cancelTaskId");
        TypedField<String> CANCELRESULT = new TypedField<>(String.class, "cancelResult");
        TypedField<String> REDLETTERNUMBER = new TypedField<>(String.class, "redLetterNumber");
        TypedField<String> APPLYSTATUS = new TypedField<>(String.class, "applyStatus");
        TypedField<LocalDateTime> APPLYTIME = new TypedField<>(LocalDateTime.class, "applyTime");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
    }

    public interface SalesBillMain {
        static Long id() {
            return 1406581300212961282L;
        }
        static String code() {
            return "salesBillMain";
        }
        TypedField<String> BUSINESSBILLTYPE = new TypedField<>(String.class, "businessBillType");
        TypedField<String> TERMINALCODE = new TypedField<>(String.class, "terminalCode");
        TypedField<String> SYSTEMORIG = new TypedField<>(String.class, "systemOrig");
        TypedField<String> STATUS = new TypedField<>(String.class, "status");
        TypedField<String> SALESBILLNO = new TypedField<>(String.class, "salesbillNo");
        TypedField<BigDecimal> AMOUNTWITHTAX = new TypedField<>(BigDecimal.class, "amountWithTax");
        TypedField<BigDecimal> OUTERDISCOUNTWITHTAX = new TypedField<>(BigDecimal.class, "outerDiscountWithTax");
        TypedField<BigDecimal> AMOUNTWITHOUTTAX = new TypedField<>(BigDecimal.class, "amountWithoutTax");
        TypedField<BigDecimal> TAXAMOUNT = new TypedField<>(BigDecimal.class, "taxAmount");
        TypedField<String> INVOICETYPE = new TypedField<>(String.class, "invoiceType");
        TypedField<String> PRICEMETHOD = new TypedField<>(String.class, "priceMethod");
        TypedField<String> REMARK = new TypedField<>(String.class, "remark");
        TypedField<String> SELLERTAXNO = new TypedField<>(String.class, "sellerTaxNo");
        TypedField<String> SELLERNAME = new TypedField<>(String.class, "sellerName");
        TypedField<String> SELLERADDRESS = new TypedField<>(String.class, "sellerAddress");
        TypedField<String> SELLERTEL = new TypedField<>(String.class, "sellerTel");
        TypedField<String> SELLERBANKNAME = new TypedField<>(String.class, "sellerBankName");
        TypedField<String> SELLERBANKACCOUNT = new TypedField<>(String.class, "sellerBankAccount");
        TypedField<String> PURCHASERNO = new TypedField<>(String.class, "purchaserNo");
        TypedField<String> CASHIERNAME = new TypedField<>(String.class, "cashierName");
        TypedField<String> CHECKERNAME = new TypedField<>(String.class, "checkerName");
        TypedField<String> INVOICERNAME = new TypedField<>(String.class, "invoicerName");
        TypedField<String> RECEIVEUSEREMAIL = new TypedField<>(String.class, "receiveUserEmail");
        TypedField<String> SALESBILLTYPE = new TypedField<>(String.class, "salesbillType");
        TypedField<String> EXT1 = new TypedField<>(String.class, "ext1");
        TypedField<String> EXT2 = new TypedField<>(String.class, "ext2");
        TypedField<String> EXT3 = new TypedField<>(String.class, "ext3");
        TypedField<String> ORIGININVOICENO = new TypedField<>(String.class, "originInvoiceNo");
        TypedField<String> ORIGININVOICECODE = new TypedField<>(String.class, "originInvoiceCode");
        TypedField<String> REDNOTIFICATION = new TypedField<>(String.class, "redNotification");
        TypedField<String> PROCESSSTATUS = new TypedField<>(String.class, "processStatus");
        TypedField<String> PROCESSRESULT = new TypedField<>(String.class, "processResult");
        TypedField<String> PROCESSREMARK = new TypedField<>(String.class, "processRemark");
        TypedField<String> PURCHASERADDRESS = new TypedField<>(String.class, "purchaserAddress");
        TypedField<String> PURCHASERBANKACCOUNT = new TypedField<>(String.class, "purchaserBankAccount");
        TypedField<String> PURCHASERBANKNAME = new TypedField<>(String.class, "purchaserBankName");
        TypedField<String> PURCHASERNAME = new TypedField<>(String.class, "purchaserName");
        TypedField<String> PURCHASERTAXNO = new TypedField<>(String.class, "purchaserTaxNo");
        TypedField<String> PURCHASERTEL = new TypedField<>(String.class, "purchaserTel");
        TypedField<String> EXT4 = new TypedField<>(String.class, "ext4");
        TypedField<String> EXT5 = new TypedField<>(String.class, "ext5");
        TypedField<String> SYSORGCODE = new TypedField<>(String.class, "sysOrgCode");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<Long> USINGSTATUS = new TypedField<>(Long.class, "usingStatus");
        TypedField<String> SELLERNO = new TypedField<>(String.class, "sellerNo");
        TypedField<String> MATCHSTATUS = new TypedField<>(String.class, "matchStatus");
    }

    public interface SalesBillDetails {
        static Long id() {
            return 1406626505695858690L;
        }
        static String code() {
            return "salesBillDetails";
        }
        TypedField<String> SALESBILLITEMNO = new TypedField<>(String.class, "salesbillItemNo");
        TypedField<String> ITEMNAME = new TypedField<>(String.class, "itemName");
        TypedField<String> ITEMSPEC = new TypedField<>(String.class, "itemSpec");
        TypedField<String> QUANTITYUNIT = new TypedField<>(String.class, "quantityUnit");
        TypedField<BigDecimal> UNITPRICE = new TypedField<>(BigDecimal.class, "unitPrice");
        TypedField<BigDecimal> DEDUCTION = new TypedField<>(BigDecimal.class, "deduction");
        TypedField<BigDecimal> QUANTITY = new TypedField<>(BigDecimal.class, "quantity");
        TypedField<BigDecimal> AMOUNTWITHOUTTAX = new TypedField<>(BigDecimal.class, "amountWithoutTax");
        TypedField<BigDecimal> TAXRATE = new TypedField<>(BigDecimal.class, "taxRate");
        TypedField<BigDecimal> TAXAMOUNT = new TypedField<>(BigDecimal.class, "taxAmount");
        TypedField<BigDecimal> AMOUNTWITHTAX = new TypedField<>(BigDecimal.class, "amountWithTax");
        TypedField<BigDecimal> OUTERDISCOUNTWITHTAX = new TypedField<>(BigDecimal.class, "outerDiscountWithTax");
        TypedField<String> GOODSTAXNO = new TypedField<>(String.class, "goodsTaxNo");
        TypedField<String> TAXCONVERTCODE = new TypedField<>(String.class, "taxConvertCode");
        TypedField<String> TAXPRE = new TypedField<>(String.class, "taxPre");
        TypedField<String> TAXPRECON = new TypedField<>(String.class, "taxPreCon");
        TypedField<String> ZEROTAX = new TypedField<>(String.class, "zeroTax");
        TypedField<String> EXT1 = new TypedField<>(String.class, "ext1");
        TypedField<String> EXT2 = new TypedField<>(String.class, "ext2");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<Long> SALESBILLID = new TypedField<>(Long.class, "salesbillId");
    }

    public interface SalesBillRelation {
        static Long id() {
            return 1407623642923315201L;
        }
        static String code() {
            return "salesBillRelation";
        }
        TypedField<String> SALESBILLID = new TypedField<>(String.class, "salesbillId");
        TypedField<String> SALESBILLNO = new TypedField<>(String.class, "salesbillNo");
        TypedField<String> RELATIONNO = new TypedField<>(String.class, "relationNo");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
    }

}
